==> haskell-servant-swagger-1.1.7-38-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-servant-swagger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant-swagger
version: 1.1.7
id: servant-swagger-1.1.7-AESoCiWMAWa3ETQ2RGaQWd
key: servant-swagger-1.1.7-AESoCiWMAWa3ETQ2RGaQWd
license: BSD-3-Clause
copyright: (c) 2015-2018, Servant contributors
maintainer: nickolay.kudasov@gmail.com
author: David Johnson, Nickolay Kudasov
homepage: https://github.com/haskell-servant/servant-swagger
synopsis: Generate Swagger specification for your servant API.
description:
    Swagger is a project used to describe and document RESTful APIs.
    Unlike Servant it is language-agnostic and thus is quite popular among developers
    in different languages. It also exists for a longer time and has more tools to work with.
    .
    This package provides means to generate Swagger specification for a Servant API
    and also to partially test whether API conforms with its specification.
    .
    Generated Swagger specification then can be used for many things such as
    .
    * displaying interactive documentation using [Swagger UI](http://swagger.io/swagger-ui/);
    .
    * generating clients and servers in many languages using [Swagger Codegen](http://swagger.io/swagger-codegen/);
    .
    * and [many others](http://swagger.io/open-source-integrations/).
category: Web, Servant, Swagger
abi: 9d13d3b45c1e410e866bd983a5bba607
exposed: True
exposed-modules:
    Servant.Swagger Servant.Swagger.Internal
    Servant.Swagger.Internal.Orphans Servant.Swagger.Internal.Test
    Servant.Swagger.Internal.TypeLevel
    Servant.Swagger.Internal.TypeLevel.API
    Servant.Swagger.Internal.TypeLevel.Every
    Servant.Swagger.Internal.TypeLevel.TMap Servant.Swagger.Test
    Servant.Swagger.TypeLevel
import-dirs: /usr/lib/ghc-8.6.5/site-local/servant-swagger-1.1.7
library-dirs: /usr/lib/ghc-8.6.5/site-local/servant-swagger-1.1.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/servant-swagger-1.1.7
hs-libraries: HSservant-swagger-1.1.7-AESoCiWMAWa3ETQ2RGaQWd
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6
    aeson-1.4.3.0-1l3nsKlFRrWAit5U2tQl5L
    aeson-pretty-0.8.7-1spRLiGt1N3KOFMKEkPeQw base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr bytestring-0.10.8.2
    hspec-2.7.0-EZdB5F9sWT52VE84f2dERP
    http-media-0.7.1.3-526FRqXrDV23kO6QPxcRZi
    insert-ordered-containers-0.2.1.0-5drpCNQ3CU2FiajkKxthg3
    lens-4.17.1-D6OjOdeP0MqEPqDMoHvH3T
    servant-0.16.0.1-Luf8PqZ2GfVEYWb5Sz63MK
    singleton-bool-0.1.4-BswWCJ6C1foFLbVlo6nj0a
    swagger2-2.3.1.1-1xOQ0J99HfjmZuZqvRmFi text-1.2.3.1
    unordered-containers-0.2.10.0-KN3bhnJnJVDChkuCyIQcSr
haddock-interfaces: /usr/share/doc/haskell-servant-swagger/html/servant-swagger.haddock
haddock-html: /usr/share/doc/haskell-servant-swagger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-swagger-1.1.7-39-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-servant-swagger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: servant-swagger
version: 1.1.7
id: servant-swagger-1.1.7-IeltYLWfF74782S0PGiGt3
key: servant-swagger-1.1.7-IeltYLWfF74782S0PGiGt3
license: BSD-3-Clause
copyright: (c) 2015-2018, Servant contributors
maintainer: nickolay.kudasov@gmail.com
author: David Johnson, Nickolay Kudasov
homepage: https://github.com/haskell-servant/servant-swagger
synopsis: Generate Swagger specification for your servant API.
description:
    Swagger is a project used to describe and document RESTful APIs.
    Unlike Servant it is language-agnostic and thus is quite popular among developers
    in different languages. It also exists for a longer time and has more tools to work with.
    .
    This package provides means to generate Swagger specification for a Servant API
    and also to partially test whether API conforms with its specification.
    .
    Generated Swagger specification then can be used for many things such as
    .
    * displaying interactive documentation using [Swagger UI](http://swagger.io/swagger-ui/);
    .
    * generating clients and servers in many languages using [Swagger Codegen](http://swagger.io/swagger-codegen/);
    .
    * and [many others](http://swagger.io/open-source-integrations/).
category: Web, Servant, Swagger
abi: 6ec4f64ee5b7c245bbc530a349ee8d69
exposed: True
exposed-modules:
    Servant.Swagger Servant.Swagger.Internal
    Servant.Swagger.Internal.Orphans Servant.Swagger.Internal.Test
    Servant.Swagger.Internal.TypeLevel
    Servant.Swagger.Internal.TypeLevel.API
    Servant.Swagger.Internal.TypeLevel.Every
    Servant.Swagger.Internal.TypeLevel.TMap Servant.Swagger.Test
    Servant.Swagger.TypeLevel
import-dirs: /usr/lib/ghc-8.6.5/site-local/servant-swagger-1.1.7
library-dirs: /usr/lib/ghc-8.6.5/site-local/servant-swagger-1.1.7
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/servant-swagger-1.1.7
hs-libraries: HSservant-swagger-1.1.7-IeltYLWfF74782S0PGiGt3
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6
    aeson-1.4.3.0-1l3nsKlFRrWAit5U2tQl5L
    aeson-pretty-0.8.7-1spRLiGt1N3KOFMKEkPeQw base-4.12.0.0
    base-compat-0.10.5-FRXoAxOVtbG2qLNIZm1tTr bytestring-0.10.8.2
    hspec-2.7.0-EZdB5F9sWT52VE84f2dERP
    http-media-0.8.0.0-L25zQqkU26CA7yE3vl2O05
    insert-ordered-containers-0.2.1.0-5drpCNQ3CU2FiajkKxthg3
    lens-4.17.1-D6OjOdeP0MqEPqDMoHvH3T
    servant-0.16.0.1-6o63H7OCYzKPgYzVoq9S5
    singleton-bool-0.1.4-BswWCJ6C1foFLbVlo6nj0a
    swagger2-2.3.1.1-1oFPjb47p9d9D88GpVtNGG text-1.2.3.1
    unordered-containers-0.2.10.0-KN3bhnJnJVDChkuCyIQcSr
haddock-interfaces: /usr/share/doc/haskell-servant-swagger/html/servant-swagger.haddock
haddock-html: /usr/share/doc/haskell-servant-swagger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
